@@ -1,12 +1,10 @@
 from typing import Tuple
 import requests
 
+from hoss.error import ServerCheckError
+
 # Set the version of the library here
-__version__ = "0.6.3"
-
-
-class ServerCheckError(Exception):
-    pass
+__version__ = "0.6.7"
 
 
 def get_server_version(server_url: str) -> Tuple[str, str]:
